pub fn insert_fake_orchard_shielded_data(tx: Transaction) -> TransactionExpand description
Returns a copy of tx carrying a dummy single-action Orchard bundle.
The bundle has no flags set and a zero value balance, for structural consensus-rule tests that only care that an Orchard bundle is present.