pub fn v6_ironwood_flags_offset(n_ironwood_actions: usize) -> usizeExpand description
The offset of the flagsOrchard byte of the Ironwood bundle, within a v6 transaction that
has no transparent and no Sapling bundle, an empty Orchard bundle, and an Ironwood bundle
with n_ironwood_actions actions.
An empty Orchard bundle is a single zero nActionsOrchard byte.